@@ -145,6 +145,8 @@ from .ops import set_seed
 from .ops import is_tensor
 from .ops import tensor_scatter_nd_update
 from .ops import diag
+from .ops import mask_select
+from .ops import eye
 # dtype
 from .ops import (
     DType, float16, float32, float64, int8, int16, int32, int64, uint8, uint16, uint32, uint64, bool, complex64,
@@ -152,7 +154,7 @@ from .ops import (
 )
 # initlizers
 from .ops import (
-    zeros, ones, constant, random_uniform, random_normal, truncated_normal, he_normal, xavier_normal, xavier_uniform
+    zeros, ones, constant, random_uniform, random_normal, truncated_normal, he_normal, he_uniform, xavier_normal, xavier_uniform
 )
 # backend
 from .ops import Reshape
