@@ -84,6 +84,7 @@ from .load_backend import QuanConv
 from .load_backend import QuanConvBn
 
 # load ops
+from .load_backend import einsum
 from .load_backend import Variable
 from .load_backend import matmul
 from .load_backend import add
@@ -197,6 +198,8 @@ from .load_backend import set_seed
 from .load_backend import is_tensor
 from .load_backend import tensor_scatter_nd_update
 from .load_backend import diag
+from .load_backend import mask_select
+from .load_backend import eye
 # dtype
 from .load_backend import (
     DType, float16, float32, float64, int8, int16, int32, int64, uint8, uint16, uint32, uint64, bool, complex64,
@@ -204,7 +207,7 @@ from .load_backend import (
 )
 # initlizers
 from .load_backend import (
-    zeros, ones, constant, random_uniform, random_normal, truncated_normal, he_normal, xavier_normal, xavier_uniform
+    zeros, ones, constant, random_uniform, random_normal, truncated_normal, he_normal, he_uniform, xavier_normal, xavier_uniform
 )
 # backend
 from .load_backend import BACKEND
@@ -243,3 +246,4 @@ from .load_backend import DepthToSpace
 from .load_backend import ClipGradByValue
 from .load_backend import ClipGradByNorm
 from .load_backend import ClipByGlobalNorm
+from .load_backend import Einsum
