@@ -9,8 +9,8 @@ from mindspore.common import dtype as mstype
 
 from mindspore.common.parameter import Parameter
 from mindspore.common.initializer import (
-    initializer, Constant, Normal, TruncatedNormal, Initializer, _assignment, _calculate_in_and_out, One, Zero,
-    _calculate_fan_in_and_fan_out
+    initializer, Constant, Normal, TruncatedNormal, Initializer, _assignment, _calculate_gain, One, Zero,
+    _calculate_fan_in_and_fan_out, _calculate_correct_fan
 )
 from mindspore.common.tensor import Tensor
 from mindspore.ops import operations as P
@@ -321,31 +321,7 @@ def truncated_normal(shape, mean=0.0, stddev=1.0, dtype=mstype.float32, seed=Non
     return Tensor(arr, dtype=dtype)
 
 
-class HeNormal(Initializer):
-    r"""
-    he_normal: It draws samples from a truncated normal distribution centered on 0 with
-    stddev = sqrt(2 / fan_in) where fan_in is the number of input units in the weight tensor.
-
-    Args:
-        arr (Array): The array to be assigned.
-
-    Returns:
-        Array, assigned array.
-    """
-
-    def __init__(self, seed=None):
-        super(HeNormal, self).__init__(seed=seed)
-        self.seed = seed
-
-    def _initialize(self, arr):
-        n_in, _ = _calculate_in_and_out(arr)
-        boundary = np.sqrt(2.0 / n_in)
-        random.seed(self.seed)
-        data = np.random.normal(-boundary, boundary, arr.shape)
-        _assignment(arr, data)
-
-
-def he_normal(shape, dtype, seed=None):
+def he_normal(shape, a = 0, mode = 'fan_in', nonlinearity='leaky_relu', dtype=mstype.float32, seed=None):
     """
     He normal initializer.
 
@@ -362,54 +338,43 @@ def he_normal(shape, dtype, seed=None):
     -------
         A tensor of the specified shape filled with he normal values.
     """
-    # shape = shape[::-1]
     arr = np.ndarray(shape)
-    init_obj = HeNormal(seed)
-    init_obj(arr)
+    fan = _calculate_correct_fan(shape, mode)
+    gain = _calculate_gain(nonlinearity, a)
+    std = gain / math.sqrt(fan)
+    data = np.random.normal(0, std, shape)
+    _assignment(arr, data)
+    return Tensor(arr, dtype=dtype)
+
+def he_uniform(shape, a = 0, mode = 'fan_in', nonlinearity='leaky_relu',dtype=mstype.float32, seed=None):
+
+    arr = np.ndarray(shape)
+    fan = _calculate_correct_fan(shape, mode)
+    gain = _calculate_gain(nonlinearity, a)
+    std = gain / math.sqrt(fan)
+    boundary = math.sqrt(3.0) * std
+    data = np.random.uniform(-boundary, boundary, shape)
+    _assignment(arr, data)
     return Tensor(arr, dtype=dtype)
 
 
-class XavierUniform(Initializer):
-
-    def __init__(self, seed=None):
-        super(XavierUniform, self).__init__(seed=seed)
-        self.seed = seed
-
-    def _initialize(self, arr):
-        n_in, n_out = _calculate_fan_in_and_fan_out(arr.shape)
-        boundary = math.sqrt(6.0 / (n_in + n_out))
-        random.seed(self.seed)
-        data = np.random.uniform(-boundary, boundary, arr.shape)
-        _assignment(arr, data)
-
-
-def xavier_uniform(shape, dtype, seed=None):
+def xavier_uniform(shape, gain = 1.0, dtype=mstype.float32, seed=None):
 
     arr = np.ndarray(shape)
-    init_obj = XavierUniform(seed)
-    init_obj(arr)
+    fan_in, fan_out = _calculate_fan_in_and_fan_out(shape)
+    bound = gain * math.sqrt(6.0 / (fan_in + fan_out))
+    data = np.random.uniform(-bound, bound, shape)
+    _assignment(arr, data)
     return Tensor(arr, dtype=dtype)
 
 
-class XavierNormal(Initializer):
-
-    def __init__(self, seed=None):
-        super(XavierNormal, self).__init__(seed=seed)
-        self.seed = seed
-
-    def _initialize(self, arr):
-        n_in, n_out = _calculate_fan_in_and_fan_out(arr.shape)
-        boundary = math.sqrt(2.0 / (n_in + n_out))
-        random.seed(self.seed)
-        data = np.random.normal(0, boundary, arr.shape)
-        _assignment(arr, data)
-
-
-def xavier_normal(shape, dtype, seed=None):
+def xavier_normal(shape, gain = 1.0, dtype=mstype.float32, seed=None):
 
     arr = np.ndarray(shape)
-    init_obj = XavierNormal(seed)
-    init_obj(arr)
+    fan_in, fan_out = _calculate_fan_in_and_fan_out(shape)
+    std = gain * math.sqrt(2.0 / float(fan_in + fan_out))
+    data = np.random.normal(0, std, shape)
+    _assignment(arr, data)
     return Tensor(arr, dtype=dtype)
 
 
@@ -607,7 +572,7 @@ def concat(values, axis):
     Concatenates tensors along one dimension.
 
     Parameters
-    ----------
+    ----------nonzero
     values : list
          A list of Tensor objects or a single Tensor
     axis : int
@@ -1829,4 +1794,48 @@ def tensor_scatter_nd_update(tensor, indices, updates):
 
 def diag(input, diagonal=0):
 
-    return ms.numpy.diag(input, diagonal)
\ No newline at end of file
+    return ms.numpy.diag(input, diagonal)
+
+def mask_select(x, mask, axis = 0):
+    if axis is None:
+        axis = 0
+    if axis < 0:
+        axis = len(x.shape) + axis
+    if x.shape == mask.shape:
+        return ms.ops.MaskedSelect()(x, mask)
+    if isinstance(mask, ms.Tensor):
+        mask = mask.asnumpy()
+    mask = np.nonzero(mask)[0].tolist()
+    if axis < 0:
+        axis = len(x.shape) + axis
+    if axis == 0:
+        return x[mask]
+    elif axis == 1:
+        return x[:, mask]
+    elif axis == 2:
+        return x[:, :, mask]
+    elif axis == 3:
+        return x[:,:,:, mask]
+
+def eye(n, m = None, dtype = None):
+    if dtype is None:
+        dtype = mstype.float32
+    return ms.numpy.eye(n, m, dtype = dtype)
+
+
+def einsum(equation, *operands):
+    if ms.__version__ < '1.7.0':
+        raise NotImplementedError("Only MindSpore versions later than 1.7.0 are supported.")
+    einsum_obj = ms.ops.Einsum(equation)
+    return einsum_obj(tuple(operands))
+
+
+class Einsum(Cell):
+    def __init__(self, equation):
+        super(Einsum, self).__init__()
+        if ms.__version__ < '1.7.0':
+            raise NotImplementedError("Only MindSpore versions later than 1.7.0 are supported.")
+        self.einsum = ms.ops.Einsum(equation)
+
+    def __call__(self, *args):
+        return self.einsum(tuple(args))
\ No newline at end of file
