@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 from torch.nn import Module as T_Module
-from .common import check_parameter, str2act, str2init, tolist, construct_graph, ModuleNode, select_attrs
+from .common import check_parameter, processing_act, str2init, tolist, construct_graph, ModuleNode, select_attrs
 from .common import _save_weights, _load_weights, _save_standard_weights_dict, _load_standard_weights_dict
 from torch.nn.parameter import Parameter
 from collections import OrderedDict
@@ -46,19 +46,7 @@ class Module(T_Module):
 
         self.name = name
 
-        if isinstance(act, str):
-            str_act = str2act(act)
-
-        if act:
-            if isinstance(act, str) and (len(act) > 5 and act[0:5] == "lrelu" or
-                                         len(act) > 10 and act[0:10] == "leaky_relu"):
-                self.act = str_act
-            elif isinstance(act, str):
-                self.act = str_act()
-            else:
-                self.act = act()
-        else:
-            self.act = act
+        self.act = processing_act(act)
 
         # Layer building state
         self._built = False
@@ -186,7 +174,7 @@ class Module(T_Module):
 
     def build_graph(self, *inputs, **kwargs):
         # Add nodes only when the composition is needed.
-        for name, layer in self.named_modules():
+        for name, layer in self._modules.items():
             if isinstance(layer, Module):
                 layer._build_graph = True
         self.set_eval()
